(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37837,       1493]*)
(*NotebookOutlinePosition[     38714,       1523]*)
(*  CellTagsIndexPosition[     38670,       1519]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ARCH", "Title",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["BRIEF ABSTRACT", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This is a curve fitting contest: find the parabola that looks the most like \
the (catenary shaped) St. Louis arch.  It could be given any time after the \
definite integral has been developed.\
\>", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GENERAL INFORMATION", "Section",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FileName:  ARCH

Full title:  A competition: Fitting the best parabola to the St. Louis Arch

Last Update: 5/22/96

Developers: 
Aaron Klebanoff, Department of Mathematics,  Rose-Hulman Institute of \
Technology, Terre Haute IN 47803 USA.

Kimberly Foltz, Mathematics and Computer Science Division,
Indiana Academy for Science, Mathematics, & Humanities, Muncie IN  47306  USA

Dave Horn, Rogers High School, Michigan City, IN  46363

Contact:  
Aaron D. Klebanoff, Department of Mathematics, 
Rose-Hulman Institute of Technology, Terre Haute IN 47803 USA. 
Phone:  812-877-8151.  Email:  Aaron.Klebanoff@Rose-Hulman.Edu.  
FAX:  812-877-3198.

Support:  
The production of this material is supported by the National Science \
Foundation under Division of Undergraduate Education grant DUE-9352849:  \
Development Site for Complex, Technology-Based Problems in Calculus with \
Applications in Science and Engineering and the  Arvin Foundation of Columbus \
IN. \
\>", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["STATEMENT OF PROBLEM", "Section",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Gateway Arch in St. Louis is in the shape of a catenary -- a function of \
the form    f(x) = fc - A(cosh[c x/L] - 1)\
\>", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
where  A = fc/[(Qb/Qt) - 1] = 68.7672,
\tc = arccosh(Qb/Qt) = 3.0022,
\tfc = Max. Height of Centroid = 625.0925,
\tQb = Max cross-section at arch base = 1262.6651,
\tQt = Min cross-section at arch top = 125.1406,
\tL = half of centroid at arch base = 299.2239.\
\>", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
All measurements are given in feet.  This is actually the shape of the \
centroid of the arch -- the set of points going through the center of the \
arch.  The data was provided by the National Park Service.\
\>", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
At first glance, the casual observer might mistake the shape of the St. Louis \
Arch for a parabola.  Test the observation by seeing  how closely you can fit \
a parabola to the arch.  Defend your notion of close.\
\>", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["KEYWORDS", "Section",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Curve Fitting, Catenary, Parabola.", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["TEACHER NOTES", "Section",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ISSUES RELATED TO THE PROBLEM ", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There are many different ways to measure distance.  Students must be \
encouraged to be open minded.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Students should also be warned that they should always attempt to quantify \
their \"best fitting\" curve.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prerequisites", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Any time during a calculus class depending on the level of sophistication \
which you expect.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time allotment - time management", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A day should be set aside to discuss curve fitting before this assignment is \
given.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expectations ", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Students should have FUN judging each others methods.", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Be prepared to deal with students who offer trivial solutions without any \
mathematical foundation.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Future payoffs", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Gives students experience with curve fitting.", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Students gain a sense of ownership due to the open nature of the problem.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extensions", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
As a challenge problem, motivated students should attempt to
(i) compute the Hausdorff distance of \"best\" fitting graphs;
(ii) determine the \"best\" fitting parabola with the Hausdorff distance \
function.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Hausdorff metric or distance is used in the study of fractals to \
determine whether two sets (which may be quite complicated) look the same.  \
Fortunately, the idea is quite simple.  To understand the Hausdorff distance \
between two curves, you have to define what you mean by the distance between \
the curves.  This in turn is easier to understand if you first define the \
distance between a point and a curve.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
1) The distance between a point and a curve is the length of the shortest \
line segment between the point and the curve.  That is,  d(x, B) = min { d \
(x, y): y in B }.

2) The distance between curve A and curve B is greatest distance among all of \
the distances between a point on A to the curve B.  That is,
    d(A, B) = max { d(x, B): x in A }.
Similarly, the distance between curve B and curve A is the greatest distance \
among all of the distances between a point B to the curve A.  At first, this \
may seem redundant, but the following example should explain that the \
definition is not symmetric:\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Suppose\tA = unit circle centered at the origin; and
\t\tB = the circle of radius 2 centered at (5, 0).\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot[{{Cos[t], Sin[t]}, {2 Cos[t] + 5, 2 Sin[t]}},
 {t, 0, 2 Pi}, AspectRatio -> Automatic]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Then, the distance from A to B = 4, while the distance from B to A = 6.

3) Finally, the Hausdorff distance is simply the maximum between the distance \
from A to B and B to A.  So, in the case of the catenary vs. parabola, call
\tA = catenary (true shape of the St. Louis Arch); and
\tB = parabola.
While it is easy to describe, the Hausdorff distance is typically hard to \
compute symbolically.  However, given an example, one can often exploit the \
geometry of the sets A and B (which may be sets of points on a curve y = \
f(x), for example) to find the distance between them.  In the following \
example, we work four examples to compare the Hausdorff distance between the \
\"best fitting\" curves found in the Possible Solutions section to the \
catenary equation for the Arch.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Example: (see the Possible Solutions section to see how g1[x], ..., g4[x] \
were found.)\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
f[x] = the St. Louis arch
g1[x] = Least Squares fit 
g2[x] = Arc Length Fit #1 (touch at vertices)
g3[x] = Arc Length Fit #2 (touch at ground)
g4[x] = Fit to three points: ground and vertex\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A = 68.7672;
c = 3.0022;
L = 299.2239;
fc = 625.0925;
f[x_] = fc - A(Cosh[c x/L]- 1);\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["g1[x_] = 652.8286904319139 - 0.006330791164684482*x^2;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["g2[x_] = 625.0925 - 0.007238154230161798*x^2;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["g3[x_] = 648.0786735587897 - 0.007238154230161798*x^2;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["g4[x_] = 625.0925 - 0.006981548027223175*x^2;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Hausdorff distance between g1[x] and f[x] is 27.7362:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Plot[{f[x], g1[x]}, {x, 0, L + 25},
 AspectRatio -> Automatic,
 PlotRange -> {0, 670}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
It's clear from the graph above that the greatest distance between either \
curve occurs on the y - axis and is easy to compute, so the Hausdorff \
distance between g1[x] and f[x] is\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["g1[0] - f[0]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
27.73619043191388\
\>", "\<\
27.7362\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Hausdorff distance between g2[x] and f[x] is 34.5409:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Plot[{f[x], g2[x]}, {x, 0, L + 10},
 AspectRatio -> Automatic,
 PlotRange -> {0, 670}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
In this case, there is clearly a place inside [0, L] where the greatest \
distance occurs.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We find the two distances described above by finding the length of the line \
perpendicular through one of the curves and measuring the length of the \
segment between them.  The Hausdorff distance is the maximum of both of \
these.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
distftog[x_] := 
 Sqrt[(1 + 1/g2'[x]^2)(FindRoot[f[x0] == g2[x] - 1/g2'[x] (x0 - x),
   {x0, x}][[1, 2]] - x)^2]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
distgtof[x_] := 
 Sqrt[(1 + 1/f'[x]^2)(FindRoot[g2[x0] == f[x] - 1/f'[x] (x0 - x),
   {x0, x}][[1, 2]] - x)^2]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Plot[{distgtof[x], distftog[x]}, {x, 0.01, L}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[distftog[x], {x, 160.4, 160.6}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[distgtof[x], {x, 192.2, 192.25}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Since both of the graphs have the same maximum, the Hausdorff distance \
between f[x] and g2[x] is 34.5409.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Hausdorff distance between g3[x] and f[x] is 25.8622:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Plot[{f[x], g3[x]}, {x, 0, L},
 AspectRatio -> Automatic,
 PlotRange -> {0, 660}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
In this case, it's not clear if the maximum occurs at the y-axis or in the \
middle of the interval.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We find the two distances described above by finding the length of the line \
perpendicular through one of the curves and measuring the length of the \
segment between them.  The Hausdorff distance is the maximum of both of \
these.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
distftog[x_] := 
 Sqrt[(1 + 1/g3'[x]^2)(FindRoot[f[x0] ==
   g3[x] - 1/g3'[x] (x0 - x),
   {x0, x}][[1, 2]] - x)^2]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
distgtof[x_] := 
 Sqrt[(1 + 1/f'[x]^2)(FindRoot[g3[x0] ==
   f[x] - 1/f'[x] (x0 - x),
   {x0, x}][[1, 2]] - x)^2]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Plot[{distgtof[x], distftog[x]}, {x, 0.01, L}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["Now we can tell that the maximum is not on the y-axis.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Plot[distftog[x], {x, 178.05, 178.1}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[distgtof[x], {x, 202.2, 202.22}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Since both of the graphs have the same maximum, the Hausdorff distance \
between f[x] and g2[x] is 25.8622.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Hausdorff distance between g4[x] and f[x] is 31.9065:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Plot[{f[x], g4[x]}, {x, 0, L},
 AspectRatio -> Automatic,
 PlotRange -> {0, 640}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
In this case, there is clearly a place inside [0, L] where the greatest \
distance occurs.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We find the two distances described above by finding the length of the line \
perpendicular through one of the curves and measuring the length of the \
segment between them.  The Hausdorff distance is the maximum of both of \
these.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
distftog[x_] := 
 Sqrt[(1 + 1/g4'[x]^2)(FindRoot[f[x0] ==
   g4[x] - 1/g4'[x] (x0 - x),
   {x0, x}][[1, 2]] - x)^2]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
distgtof[x_] := 
 Sqrt[(1 + 1/f'[x]^2)(FindRoot[g4[x0] ==
   f[x] - 1/f'[x] (x0 - x),
   {x0, x}][[1, 2]] - x)^2]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Plot[{distgtof[x], distftog[x]}, {x, 0.01, L}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[distftog[x], {x, 158.5, 158.55}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[distgtof[x], {x, 187.5, 187.7}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Since both of the graphs have the same maximum, the Hausdorff distance \
between f[x] and g2[x] is 31.9065.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
So measuring by Hausdorff distance, one could say that g3[x] gives the best \
fit.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["References and Sources", "Subsection",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
U.S. National Park Service
URL: http://www.st-louis.mo.us/st-louis/arch/catenary.html\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["POSSIBLE SOLUTION(S)", "Section",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Least Squares Regression", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A = 68.7672;
c = 3.0022;
L = 299.2239;
fc = 625.0925;
f = fc - A(Cosh[c x/L]- 1);\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
The parabola  which best models the Gateway Arch will have symmetry with \
respect to the y-axis.  Thus, it will be a quadratic function with linear \
coefficient zero.  A general quadratic of this type can be expressed as \
follows, where p1 and p2 are parameters. \
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["g = p1 x^2 + p2;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
One way of finding the parabolic curve which best fits the catenary is to \
measure the difference between the curves; i.e., consider f(x) - g(x).  \
However, if the curves intersect, then on some intervals this difference will \
be positive and on some it will be negative.  Even though the differences may \
be large in magnitude, the opposite signs allow for the possibility that the \
differences will in effect \"cancel\". \
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
One way to force the  difference to be positive is to express the difference \
as f(x) - g(x) on subintervals where f(x) > g(x) and as g(x) - f(x) on \
subintervals where g(x)> f(x).  This requires finding the point(s) of \
intersection of the curves (which is not necessarily an easy task.)  Another \
way to eliminate the difficulty of the negative differences is to use the \
absolute value of the difference f(x) - g(x), but this causes complications \
in the subsequent integration calculations if using current computer algebra \
systems.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
These problems are eliminated by squaring the difference.  The expression
    ( f(x) - g(x) )^2 
will give a (positive) measure of the square difference between the two \
curves at any point.  The total difference is given by integrating over the \
length of the curves.  Due to the symmetry in our problem, it is necessary \
only to integrate from 0 to the right end point.  The parabola will best fit \
the catenary when total square error is minimized.  Since we are performing \
what is know as a least squares regression, we refer to the total square \
error as SE (for Square Error), and we remark that this quantity depends on \
the parameters p1 and p2 for the candidate fitting curve.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["SE = Integrate[(f - g)^2, {x, 0, L}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
7.314524452645506*10^7 - 
 
  5.585609413931427*10^9*p1 + 
 
  4.797460318496594*10^11*p1^2 - 
 
  277611.7654987686*p2 + 
 
  1.786066308707984*10^7*p1*p2 + 
 
  299.2239000000001*p2^2\
\>", "\<\
          7             9
7.31452 10  - 5.58561 10  p1 + 
 
            11   2
  4.79746 10   p1  - 
 
  277612. p2 + 
 
            7                   2
  1.78607 10  p1 p2 + 299.224 p2\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
To minimize the square error, we find its critical points by finding the \
zeroes of its derivatives.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
derSEp1 = D[SE, p1];
derSEp2 = D[SE, p2];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
By setting each partial derivative equal to zero and solving the resulting \
system of equations simultaneously, we find the values of p1 and p2 that \
minimize the sum of the square differences. \
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["sol = Solve[{derSEp1 == 0,derSEp2 == 0}, {p1, p2}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{p1 -> -0.006330791164684482, 
 
   p2 -> 652.8286904319139}}\
\>", "\<\
{{p1 -> -0.00633079, 
 
   p2 -> 652.829}}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
How does the least squares parabola compare to the actual arch?  We will \
retrieve the values for p1 and p2 from the above solution and then plot each \
curve to see.  The true arch is the solid curve and the approximating curve \
is dashed.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
p1star = p1 /. sol[[1,1]];
p2star = p2 /. sol[[1,2]];
bestg = g /. {p1 -> p1star, p2 -> p2star}\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
652.8286904319139 - 
 
  0.006330791164684482*x^2\
\>", "\<\
                      2
652.829 - 0.00633079 x\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Plot[{f, bestg}, {x, -L, L},
 AspectRatio -> Automatic,
 PlotStyle -> {{AbsoluteThickness[2]},
               {AbsoluteThickness[3],
                AbsoluteDashing[{3, 6}]}},
 AxesLabel -> {\"[ft]\", \"height [ft]\"}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Its important to note that the fitting curve is only best fitting over the \
length of the true arch.  It's a bit more complicated to get a best fitting \
curve all the way to the ground in the least squares sense.  We offer a \
solution to that case in ISSUES IN SOLUTIONS.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Equal Arc Length (2 sub cases)", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
This \"solution\" rests on the assumption that the \"best\" parabola will \
have the same arc length as the catenary.  The first step is to find this \
length.   The following code finds this using the standard formula and taking \
advantage of the symmetry of the curve.
\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[f];
A = 68.7672;
c = 3.0022;
L = 299.2239;
fc = 625.0925;
f[x_] = fc - A (Cosh[c x/L]- 1);\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["lengthcat = NIntegrate[2 Sqrt[1 + (f'[x])^2], {x, 0, L}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
1480.275796090812\
\>", "\<\
1480.28\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Thus, our goal is to find a parabola with arc length of 1480.28 feet.

As in the previous solution, we assume symmetry with respect to the y-axis.  \
Thus, our parabola will not have a linear term yielding an expression of the \
form\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["g = p1 x^2 + p2", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
p2 + p1*x^2\
\>", "\<\
         2
p2 + p1 x\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
We want to find the values p1 and p2 that will make the arc length of the \
parabola 1480.28 feet.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
In the process of computing the arc length of g, the parameter p2 drops out \
resulting in\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
lengthparab = Integrate[2 Sqrt[1+(2 p1 x)^2],{x, 0, L}];
p1star = p1 /. FindRoot[lengthparab == lengthcat,{p1, -1}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
-0.007238154230161796\
\>", "\<\
-0.00723815\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Thus, the leading coefficient of the \"best\" parabola is -0.00723815.  \
However, it is not possible to isolate the second parameter, p2, because the \
parameter, in the absence of a linear term, determines vertical translation, \
and vertical translation does not change the arc length.  Thus, we are free \
to choose any value of p2 we wish.  There are two obvious choices:\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
1.  Make the vertex of the parabola coincide with the apex of the arch; i.e. \
let p2 = fc from   above.\t\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
p2star = fc;
bestg1 =  g /. {p1 -> p1star, p2 -> p2star}\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
625.0925 - 0.007238154230161796*
 
   x^2\
\>", "\<\
                       2
625.0925 - 0.00723815 x\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Plot[{f[x], bestg1}, {x, -L, L},
 AspectRatio -> Automatic,
 PlotStyle -> {{AbsoluteThickness[2]},
               {AbsoluteThickness[3],
                AbsoluteDashing[{3, 6}]}},
 AxesLabel -> {\"[ft]\", \"height [ft]\"}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This  graph looks pretty good near the top, but to achieve the desired arc \
lengths, the ends are below the ground.  It is questionable whether it is \
fair to say the curves have the same length since the catenary is entirely \
above ground but the ends of the parabola are buried.  \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
2.  Make the parabola and the arch hit the ground at the same points.  For \
this to occur, the parabola must pass through the point determined by \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\

root = FindRoot[f[x] == 0,{x, 300}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{x -> 299.226428346399}\
\>", "\<\
{x -> 299.226}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
xint = x /. root;
p2star = p2 /. FindRoot[0 == p1star xint^2 + p2, {p2,600}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
648.0786735587895\
\>", "\<\
648.079\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["bestg2 = g /. {p1 -> p1star, p2 -> p2star}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
648.0786735587895 - 
 
  0.007238154230161796*x^2\
\>", "\<\
                      2
648.079 - 0.00723815 x\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Plot[{f[x], bestg2}, {x, -L, L},
 AspectRatio -> Automatic,
 PlotStyle -> {{AbsoluteThickness[2]},
               {AbsoluteThickness[3],
                AbsoluteDashing[{3, 6}]}},
 AxesLabel -> {\"[ft]\", \"height [ft]\"}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Because this parabola is entirely above ground, in one important sense it is \
better than the previous one.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3 point solution", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Another choice for the \"best\" parabola might be the unique parabola that \
shares three important points with the catenary.  These points are the apex \
and the two intersections with the ground (the x-axis).  The equation of this \
parabola is again of the form g(x) = p1 x^2 + p2 due to the symmetry about \
the vertical axis.  Furthermore, since the vertex is on the vertical axis, we \
know that p2 = fc which yields the functional form\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["g = p1 x^2 + fc", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
625.0925 + p1*x^2\
\>", "\<\
               2
625.0925 + p1 x\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
We choose p1 so that the x-intercept of the parabola is at (L, 0) -- the \
x-intercept of the catenary.  Substituting L into g and setting it equal to \
zero yields\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["p1star = p1 /. Flatten[Solve[(g /. x -> L) == 0, p1]]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
-0.006981548027223175\
\>", "\<\
-0.00698155\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["bestg = g /. {p1 -> p1star, p2 -> p2star}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
625.0925 - 0.006981548027223175*
 
   x^2\
\>", "\<\
                       2
625.0925 - 0.00698155 x\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Plot[{f[x], bestg}, {x, -L, L},
 AspectRatio -> Automatic,
 PlotStyle -> {{AbsoluteThickness[2]},
               {AbsoluteThickness[3],
                AbsoluteDashing[{3, 6}]}},
 AxesLabel -> {\"[ft]\", \"height [ft]\"}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hausdorff distance (see Extensions)", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
It is difficult to obtain the parabola that is closest in the Hausdorff \
distance to the true arch, but it provides a nice way to judge the other \
solutions.  Here is a summary which is shown in detail in the Extensions \
section, a subsection of Teacher Notes.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
From best to worst using Hausdorff distance:
   (1) Setting the arc lengths equal and matching the curves at the ground
   (2) Minimizing the distance in the least squares sense
   (3) Matching curves at the vertex and ground
   (4) Setting the arc lengths equal and matching at the vertex
The four cases are shown below from best to worst fit in the Hausdorff sense.\
\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ISSUES IN SOLUTION", "Section",
  PageBreakWithin->Automatic,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Probably the most natural measure of distance for the students would be to \
make the area between the curves as small as possible.  However, this \
requires that we determine the points where the curves intersect which can \
only be done numerically.  This provides a good motivation for the using \
least squares instead of the absolute value of the difference.\
\>", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Probably the simplest solution is the 3 point fit solution (see Solutions).  \
As shown under Extensions, it's actually not a bad solution and it's not even \
the worst of the four offered.  So, you should also make sure that students \
should have a way to compare the solutions in other than visual ways.  (For \
example, all solutions can be compared by the criteria of best fit by least \
squares.)\
\>", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
In the Least Squares fit, you do not know at the onset where the \"best \
fitting\" curve will hit the ground.  A more complicated yet more satisfying \
solution is offered below.\
\>", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A = 68.7672;
c = 3.0022;
L = 299.2239;
fc = 625.0925;
f = fc - A(Cosh[c x/L]- 1);
g = -p1 x^2 + p2;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["zero = x /. Flatten[Solve[g == 0, x]]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
-(p2^(1/2)/p1^(1/2))\
\>", "\<\
  Sqrt[p2]
-(--------)
  Sqrt[p1]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["SE = Integrate[(f - g)^2, {x, 0, zero}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
(-483805.7471820101*p2^(1/2))/
 
   p1^(1/2) + 
 
  (925.146266666667*p2^(3/2))/
 
   p1^(1/2) - 
 
  (0.5333333333333336*p2^(5/2))/
 
   p1^(1/2) - 
 
  2.7324652642772*10^6*p1^(1/2)*
 
   p2^(1/2)*Cosh[(0.010033289453\\
 
        14863*p2^(1/2))/p1^(1/2)]
 
    + 9.51129517087066*10^6*
 
   Sinh[(0.01003328945314863*
 
       p2^(1/2))/p1^(1/2)] + 
 
  2.723399217212559*10^8*p1*
 
   Sinh[(0.01003328945314863*
 
       p2^(1/2))/p1^(1/2)] - 
 
  117830.9421332397*
 
   Sinh[(0.02006657890629726*
 
       p2^(1/2))/p1^(1/2)]\
\>", "\<\
-483806. Sqrt[p2]
----------------- + 
    Sqrt[p1]
 
            3/2
  925.146 p2
  ------------- - 
    Sqrt[p1]
 
             5/2
  0.533333 p2
  -------------- - 
     Sqrt[p1]
 
            6
  2.73247 10  Sqrt[p1] Sqrt[p2] 
 
        0.0100333 Sqrt[p2]
   Cosh[------------------] + 
             Sqrt[p1]
 
           6
  9.5113 10  Sinh[
 
     0.0100333 Sqrt[p2]
     ------------------] + 
          Sqrt[p1]
 
           8
  2.7234 10  p1 
 
        0.0100333 Sqrt[p2]
   Sinh[------------------] - 
             Sqrt[p1]
 
  117831. Sinh[
 
     0.0200666 Sqrt[p2]
     ------------------]
          Sqrt[p1]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
derSEp1 = D[SE, p1];
derSEp2 = D[SE, p2];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
By setting each partial derivative equal to zero and solving the resulting \
system of equations simultaneously, we find the values of p1 and p2 that \
minimize the sum of the square differences. \
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
sol = FindRoot[{derSEp1==0, derSEp2==0},
 {p1, 0.005}, {p2, 652}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{p1 -> 0.006848385337222574, 
 
  p2 -> 662.6324709987787}\
\>", "\<\
{p1 -> 0.00684839, p2 -> 662.632}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
How does the least squares parabola compare to the actual arch?  We will \
retrieve the values for p1 and p2 from the above solution and then plot each \
curve to see.  The true arch is the solid curve and the approximating curve \
is dashed.\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
p1star = p1 /. sol[[1]];
p2star = p2 /. sol[[2]];
bestg = g /. {p1 -> p1star, p2 -> p2star}\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
662.6324709987787 - 
 
  0.006848385337222574*x^2\
\>", "\<\
                      2
662.632 - 0.00684839 x\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["int = Max[L, -zero /. {p1 -> p1star, p2 -> p2star}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
311.0586354684687\
\>", "\<\
311.059\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Plot[{f, bestg}, {x, -int, int},
 AspectRatio -> Automatic,
 PlotStyle -> {{AbsoluteThickness[2]},
               {AbsoluteThickness[3],
                AbsoluteDashing[{3, 6}]}},
 AxesLabel -> {\"[ft]\", \"height [ft]\"}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1012, 758},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 84, 2, 171, "Title",
  PageBreakWithin->Automatic],

Cell[CellGroupData[{
Cell[1885, 59, 66, 1, 89, "Section"],
Cell[1954, 62, 256, 5, 94, "Subsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2247, 72, 101, 2, 89, "Section",
  PageBreakWithin->Automatic],
Cell[2351, 76, 1054, 30, 718, "Subsection",
  PageBreakWithin->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[3442, 111, 102, 2, 57, "Section",
  PageBreakWithin->Automatic],
Cell[3547, 115, 214, 5, 94, "Subsection",
  PageBreakWithin->Automatic],
Cell[3764, 122, 353, 9, 198, "Subsection",
  PageBreakWithin->Automatic],
Cell[4120, 133, 300, 6, 94, "Subsection",
  PageBreakWithin->Automatic],
Cell[4423, 141, 306, 6, 94, "Subsection",
  PageBreakWithin->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[4766, 152, 90, 2, 57, "Section",
  PageBreakWithin->Automatic],
Cell[4859, 156, 119, 2, 68, "Subsection",
  PageBreakWithin->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[5015, 163, 95, 2, 57, "Section",
  PageBreakWithin->Automatic],

Cell[CellGroupData[{
Cell[5135, 169, 115, 2, 68, "Subsection",
  PageBreakWithin->Automatic],
Cell[5253, 173, 166, 4, 61, "Subsubsection"],
Cell[5422, 179, 172, 4, 61, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5631, 188, 98, 2, 68, "Subsection",
  PageBreakWithin->Automatic],
Cell[5732, 192, 159, 4, 61, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5928, 201, 117, 2, 68, "Subsection",
  PageBreakWithin->Automatic],
Cell[6048, 205, 151, 4, 61, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6236, 214, 98, 2, 68, "Subsection",
  PageBreakWithin->Automatic],
Cell[6337, 218, 111, 1, 61, "Subsubsection"],
Cell[6451, 221, 166, 4, 61, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6654, 230, 99, 2, 68, "Subsection",
  PageBreakWithin->Automatic],
Cell[6756, 234, 103, 1, 61, "Subsubsection"],
Cell[6862, 237, 139, 3, 61, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7038, 245, 95, 2, 68, "Subsection",
  PageBreakWithin->Automatic],
Cell[7136, 249, 274, 6, 70, "Subsubsection"],
Cell[7413, 257, 486, 8, 70, "Subsubsection"],
Cell[7902, 267, 676, 13, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[8603, 284, 169, 4, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[8797, 292, 159, 4, 70, "Input"],
Cell[8959, 298, 115, 5, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[9101, 307, 852, 15, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[9978, 326, 154, 4, 70, "Subsubsection"],
Cell[10135, 332, 246, 7, 70, "Text"],
Cell[10384, 341, 143, 7, 70, "Input"],
Cell[10530, 350, 104, 1, 70, "Input"],
Cell[10637, 353, 95, 1, 70, "Input"],
Cell[10735, 356, 104, 1, 70, "Input"],
Cell[10842, 359, 95, 1, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10974, 365, 117, 2, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[11116, 371, 144, 5, 70, "Input"],
Cell[11263, 378, 115, 5, 70, "Output"]
}, Open  ]],
Cell[11393, 386, 239, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[11657, 395, 62, 1, 70, "Input"],
Cell[11722, 398, 111, 5, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11882, 409, 117, 2, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[12024, 415, 144, 5, 70, "Input"],
Cell[12171, 422, 115, 5, 70, "Output"]
}, Open  ]],
Cell[12301, 430, 147, 4, 70, "Text"],
Cell[12451, 436, 289, 6, 70, "Text"],
Cell[12743, 444, 170, 5, 70, "Input"],
Cell[12916, 451, 168, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[13109, 460, 96, 1, 70, "Input"],
Cell[13208, 463, 115, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13360, 473, 86, 1, 70, "Input"],
Cell[13449, 476, 115, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13601, 486, 87, 1, 70, "Input"],
Cell[13691, 489, 115, 5, 70, "Output"]
}, Open  ]],
Cell[13821, 497, 164, 4, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14022, 506, 117, 2, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[14164, 512, 139, 5, 70, "Input"],
Cell[14306, 519, 115, 5, 70, "Output"]
}, Open  ]],
Cell[14436, 527, 157, 4, 70, "Text"],
Cell[14596, 533, 289, 6, 70, "Text"],
Cell[14888, 541, 173, 6, 70, "Input"],
Cell[15064, 549, 171, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[15260, 559, 96, 1, 70, "Input"],
Cell[15359, 562, 115, 5, 70, "Output"]
}, Open  ]],
Cell[15489, 570, 103, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[15617, 575, 87, 1, 70, "Input"],
Cell[15707, 578, 115, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15859, 588, 87, 1, 70, "Input"],
Cell[15949, 591, 115, 5, 70, "Output"]
}, Open  ]],
Cell[16079, 599, 164, 4, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16280, 608, 117, 2, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[16422, 614, 139, 5, 70, "Input"],
Cell[16564, 621, 115, 5, 70, "Output"]
}, Open  ]],
Cell[16694, 629, 147, 4, 70, "Text"],
Cell[16844, 635, 289, 6, 70, "Text"],
Cell[17136, 643, 173, 6, 70, "Input"],
Cell[17312, 651, 171, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[17508, 661, 96, 1, 70, "Input"],
Cell[17607, 664, 115, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17759, 674, 87, 1, 70, "Input"],
Cell[17849, 677, 115, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18001, 687, 86, 1, 70, "Input"],
Cell[18090, 690, 115, 5, 70, "Output"]
}, Open  ]],
Cell[18220, 698, 164, 4, 70, "Text"]
}, Open  ]],
Cell[18399, 705, 148, 4, 70, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[18584, 714, 107, 2, 42, "Subsection",
  PageBreakWithin->Automatic],
Cell[18694, 718, 151, 4, 83, "Subsubsection"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[18894, 728, 102, 2, 57, "Section",
  PageBreakWithin->Automatic],

Cell[CellGroupData[{
Cell[19021, 734, 79, 1, 68, "Subsection"],
Cell[19103, 737, 139, 7, 133, "Input"],

Cell[CellGroupData[{
Cell[19267, 748, 332, 6, 105, "Subsubsection"],
Cell[19602, 756, 66, 1, 41, "Input"]
}, Open  ]],
Cell[19683, 760, 494, 8, 127, "Subsubsection"],
Cell[20180, 770, 610, 10, 149, "Subsubsection"],

Cell[CellGroupData[{
Cell[20815, 784, 759, 12, 193, "Subsubsection"],

Cell[CellGroupData[{
Cell[21599, 800, 86, 1, 41, "Input"],
Cell[21688, 803, 459, 24, 160, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22196, 833, 167, 4, 61, "Subsubsection"],
Cell[22366, 839, 99, 4, 64, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22502, 848, 262, 5, 83, "Subsubsection"],

Cell[CellGroupData[{
Cell[22789, 857, 100, 1, 41, "Input"],
Cell[22892, 860, 191, 9, 65, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23132, 875, 308, 6, 105, "Subsubsection"],

Cell[CellGroupData[{
Cell[23465, 885, 153, 5, 87, "Input"],
Cell[23621, 892, 182, 8, 52, "Output"]
}, Open  ]],
Cell[23818, 903, 277, 8, 156, "Input"]
}, Open  ]],
Cell[24110, 914, 340, 6, 105, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[24487, 925, 85, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[24597, 930, 338, 7, 70, "Subsubsection"],
Cell[24938, 939, 154, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[25117, 951, 106, 1, 70, "Input"],
Cell[25226, 954, 111, 5, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25386, 965, 299, 7, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[25710, 976, 65, 1, 70, "Input"],
Cell[25778, 979, 118, 6, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[25923, 989, 164, 4, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[26112, 997, 156, 4, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[26293, 1005, 173, 4, 70, "Input"],
Cell[26469, 1011, 119, 5, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26637, 1022, 442, 7, 70, "Subsubsection"],
Cell[27082, 1031, 163, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[27270, 1039, 114, 4, 70, "Input"],
Cell[27387, 1045, 176, 8, 70, "Output"]
}, Open  ]],
Cell[27578, 1056, 281, 8, 70, "Input"],
Cell[27862, 1066, 342, 6, 70, "Text"],
Cell[28207, 1074, 204, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[28436, 1082, 94, 4, 70, "Input"],
Cell[28533, 1088, 124, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28694, 1098, 134, 4, 70, "Input"],
Cell[28831, 1104, 111, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28979, 1114, 92, 1, 70, "Input"],
Cell[29074, 1117, 182, 8, 70, "Output"]
}, Open  ]],
Cell[29271, 1128, 281, 8, 70, "Input"],
Cell[29555, 1138, 165, 4, 70, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[29769, 1148, 71, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[29865, 1153, 508, 8, 127, "Subsubsection"],

Cell[CellGroupData[{
Cell[30398, 1165, 65, 1, 41, "Input"],
Cell[30466, 1168, 136, 6, 52, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30651, 1180, 230, 5, 83, "Subsubsection"],

Cell[CellGroupData[{
Cell[30906, 1189, 103, 1, 41, "Input"],
Cell[31012, 1192, 119, 5, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31168, 1202, 91, 1, 41, "Input"],
Cell[31262, 1205, 176, 8, 52, "Output"]
}, Open  ]],
Cell[31453, 1216, 280, 8, 156, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[31782, 1230, 90, 1, 42, "Subsection"],
Cell[31875, 1233, 329, 6, 105, "Subsubsection"],
Cell[32207, 1241, 435, 9, 171, "Subsubsection"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32691, 1256, 100, 2, 89, "Section",
  PageBreakWithin->Automatic],
Cell[32794, 1260, 426, 7, 146, "Subsection"],
Cell[33223, 1269, 465, 8, 146, "Subsection"],

Cell[CellGroupData[{
Cell[33713, 1281, 242, 5, 94, "Subsection"],
Cell[33958, 1288, 157, 8, 156, "Input"],

Cell[CellGroupData[{
Cell[34140, 1300, 87, 1, 41, "Input"],
Cell[34230, 1303, 140, 7, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34407, 1315, 89, 1, 70, "Input"],
Cell[34499, 1318, 1239, 78, 565, "Output"]
}, Open  ]],
Cell[35753, 1399, 99, 4, 64, "Input"],

Cell[CellGroupData[{
Cell[35877, 1407, 262, 5, 83, "Subsubsection"],

Cell[CellGroupData[{
Cell[36164, 1416, 123, 4, 64, "Input"],
Cell[36290, 1422, 178, 7, 38, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36517, 1435, 308, 6, 105, "Subsubsection"],

Cell[CellGroupData[{
Cell[36850, 1445, 149, 5, 87, "Input"],
Cell[37002, 1452, 182, 8, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37221, 1465, 101, 1, 41, "Input"],
Cell[37325, 1468, 111, 5, 38, "Output"]
}, Open  ]],
Cell[37451, 1476, 281, 8, 156, "Input"],
Cell[37735, 1486, 50, 1, 41, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

